@@ -4,6 +4,7 @@
 
 #include <gtkmm.h>
 #include <glibtop/cpu.h>
+#include <handy.h>
 
 #include <algorithm>
 
@@ -33,6 +34,7 @@ struct ProcConfig
       : update_interval(0),
 	graph_update_interval(0),
 	disks_update_interval(0),
+	graph_data_points(0),
 	mem_color(),
 	swap_color(),
 	net_in_color(),
@@ -41,9 +43,14 @@ struct ProcConfig
 	frame_color(),
 	num_cpus(0),
 	solaris_mode(false),
+	process_memory_in_iec(true),
+	logarithmic_scale(false),
 	draw_stacked(false),
 	draw_smooth(true),
-	network_in_bits(false)
+	resources_memory_in_iec(true),
+	network_in_bits(false),
+	network_total_unit(false),
+	network_total_in_bits(false)
     {
       std::fill(&this->cpu_color[0], &this->cpu_color[GLIBTOP_NCPU], GdkRGBA());
     }
@@ -51,6 +58,7 @@ struct ProcConfig
     int             update_interval;
     int             graph_update_interval;
     int             disks_update_interval;
+    int             graph_data_points;
     GdkRGBA         cpu_color[GLIBTOP_NCPU];
     GdkRGBA         mem_color;
     GdkRGBA         swap_color;
@@ -60,9 +68,14 @@ struct ProcConfig
     GdkRGBA         frame_color;
     gint            num_cpus;
     bool solaris_mode;
+    bool process_memory_in_iec;
+    bool logarithmic_scale;
     bool draw_stacked;
     bool draw_smooth;
+    bool resources_memory_in_iec;
     bool network_in_bits;
+    bool network_total_unit;
+    bool network_total_in_bits;
 };
 
 
@@ -87,7 +100,7 @@ MutableProcInfo()
     disk_read_bytes_current(0ULL),
     disk_write_bytes_current(0ULL),
     status(0U),
-    pcpu(0U),
+    pcpu(0),
     nice(0)
     {
     }
@@ -118,7 +131,7 @@ MutableProcInfo()
     guint64 disk_read_bytes_current;
     guint64 disk_write_bytes_current;
     guint status;
-    guint pcpu;
+    gdouble pcpu;
     gint nice;
     std::string cgroup_name;
 
@@ -227,7 +240,7 @@ public:
     PrettyTable      *pretty_table;
 
     Glib::RefPtr<Gio::Settings> settings;
-    GtkApplicationWindow *main_window;
+    HdyApplicationWindow *main_window;
 
     unsigned         frequency;
 
