@@ -22,7 +22,7 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <libhandy-1/handy.h>
+#include <handy.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -256,6 +256,10 @@ create_sys_view (GsmApplication *app, GtkBuilder * builder)
         }
         title_text = g_strdup_printf(title_template, label_text);
         label = GTK_LABEL (gtk_label_new (label_text));
+        gtk_label_set_xalign(label, 0.0);
+        if(app->config.num_cpus >=10) {
+            gtk_label_set_width_chars(label, log10(app->config.num_cpus)+1+4);
+        }
         gsm_color_button_set_title(color_picker, title_text);
         g_free(title_text);
         gtk_box_pack_start (temp_hbox, GTK_WIDGET (label), FALSE, FALSE, 6);
@@ -266,6 +270,7 @@ create_sys_view (GsmApplication *app, GtkBuilder * builder)
 
         /* Reserve some space to avoid the layout changing with the values. */
         gtk_label_set_width_chars(cpu_label, 6);
+        gtk_label_set_xalign(cpu_label, 1.0);
         gtk_widget_set_valign (GTK_WIDGET (cpu_label), GTK_ALIGN_CENTER);
         gtk_widget_set_halign (GTK_WIDGET (cpu_label), GTK_ALIGN_START);
         gtk_box_pack_start (temp_hbox, GTK_WIDGET (cpu_label), FALSE, FALSE, 0);
@@ -393,6 +398,7 @@ on_activate_about (GSimpleAction *, GVariant *, gpointer data)
         "Chris Kühl",
         "Robert Roth",
         "Stefano Facchini",
+        "Jacob Barkdull",
         NULL
     };
 
@@ -698,7 +704,6 @@ create_main_window (GsmApplication *app)
     GdkDisplay *display;
     GdkMonitor *monitor;
     GdkRectangle monitor_geometry;
-    const char* session;
 
     int width, height, xpos, ypos;
 
@@ -715,19 +720,6 @@ create_main_window (GsmApplication *app)
     gtk_application_window_set_help_overlay (GTK_APPLICATION_WINDOW (app->main_window),
                                              GTK_SHORTCUTS_WINDOW (gtk_builder_get_object (builder, "help_overlay")));
 
-    session = g_getenv ("XDG_CURRENT_DESKTOP");
-    if (session && !strstr (session, "GNOME")){
-        GtkBox *mainbox;
-        HdyHeaderBar *headerbar;
-
-        mainbox = GTK_BOX (gtk_builder_get_object (builder, "main_box"));
-        headerbar = HDY_HEADER_BAR (gtk_builder_get_object (builder, "header_bar"));
-        gtk_style_context_remove_class (gtk_widget_get_style_context (GTK_WIDGET (headerbar)), "titlebar");
-        gtk_window_set_titlebar (GTK_WINDOW (main_window), NULL);
-        hdy_header_bar_set_show_close_button (headerbar, FALSE);
-        gtk_box_pack_start (mainbox, GTK_WIDGET (headerbar), FALSE, FALSE, 0);
-    }
-
     g_settings_get (app->settings->gobj(), GSM_SETTING_WINDOW_STATE, "(iiii)",
                     &width, &height, &xpos, &ypos);
     
