@@ -14,16 +14,15 @@
 #include "systemd.h"
 #include "util.h"
 
-static GtkDialog *prefs_dialog = NULL;
+static HdyPreferencesWindow *prefs_dialog = NULL;
 
-static void
-prefs_dialog_button_pressed (GtkDialog *dialog, gint id, gpointer data)
+static gboolean
+prefs_dialog_delete_event (GtkWidget *widget, GdkEvent *event, gpointer data)
 {
-    gtk_widget_destroy (GTK_WIDGET (dialog));
     prefs_dialog = NULL;
+    return FALSE;
 }
 
-
 class SpinButtonUpdater
 {
 public:
@@ -43,7 +42,7 @@ private:
 
     void update(GtkSpinButton* spin)
     {
-        int new_value = int(1000 * gtk_spin_button_get_value(spin));
+        int new_value = 1000 * gtk_spin_button_get_value(spin);
 
         GsmApplication::get()->settings->set_int(this->key, new_value);
 
@@ -53,6 +52,34 @@ private:
     const string key;
 };
 
+class ScaleUpdater
+{
+public:
+	ScaleUpdater(const string& key)
+	    : key(key)
+	{ }
+
+	static gboolean callback(GtkRange *range, gpointer data)
+	{
+		ScaleUpdater* updater = static_cast<ScaleUpdater*>(data);
+		updater->update(range);
+		return FALSE;
+	}
+
+private:
+
+	void update(GtkRange* range)
+	{
+		int new_value = gtk_range_get_value(range);
+
+		GsmApplication::get()->settings->set_int(this->key, new_value);
+
+		procman_debug("set %s to %d", this->key.c_str(), new_value);
+	}
+
+	const string key;
+};
+
 static void
 field_toggled (const gchar *gsettings_parent, gchar *path_str, gpointer data)
 {
@@ -84,8 +111,8 @@ field_toggled (const gchar *gsettings_parent, gchar *path_str, gpointer data)
 
 }
 
-static void 
-field_row_activated ( GtkTreeView *tree, GtkTreePath *path, 
+static void
+field_row_activated ( GtkTreeView *tree, GtkTreePath *path,
                       GtkTreeViewColumn *column, gpointer data)
 {
     GtkTreeModel * model = gtk_tree_view_get_model (tree);
@@ -132,13 +159,13 @@ create_field_page(GtkBuilder* builder, GtkTreeView *tree, const gchar *widgetnam
     gtk_tree_view_column_set_attributes (column, cell,
                                          "active", 0,
                                          NULL);
-    if(!g_strcmp0(widgetname, "proctree")) 
+    if(!g_strcmp0(widgetname, "proctree"))
         g_signal_connect (G_OBJECT (cell), "toggled", G_CALLBACK (proc_field_toggled), model);
-    else if(!g_strcmp0(widgetname, "disktreenew")) 
+    else if(!g_strcmp0(widgetname, "disktreenew"))
         g_signal_connect (G_OBJECT (cell), "toggled", G_CALLBACK (disk_field_toggled), model);
-        
+
     g_signal_connect (G_OBJECT (GTK_TREE_VIEW (treeview)), "row-activated", G_CALLBACK (field_row_activated), (gpointer)widgetname);
-    
+
     gtk_tree_view_column_set_clickable (column, TRUE);
     gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 
@@ -199,12 +226,12 @@ create_preferences_dialog (GsmApplication *app)
     static SBU interval_updater("update-interval");
     static SBU graph_interval_updater("graph-update-interval");
     static SBU disks_interval_updater("disks-interval");
+    static ScaleUpdater graph_points_updater("graph-data-points");
 
-    GtkNotebook *notebook;
     GtkAdjustment *adjustment;
     GtkSpinButton *spin_button;
-    GtkCheckButton *check_button;
-    GtkCheckButton *smooth_button;
+    GtkSwitch *check_switch;
+    GtkSwitch *smooth_switch;
     GtkBuilder *builder;
     gfloat update;
 
@@ -214,9 +241,7 @@ create_preferences_dialog (GsmApplication *app)
     builder = gtk_builder_new();
     gtk_builder_add_from_resource (builder, "/org/gnome/gnome-system-monitor/data/preferences.ui", NULL);
 
-    prefs_dialog = GTK_DIALOG (gtk_builder_get_object (builder, "preferences_dialog"));
-
-    notebook = GTK_NOTEBOOK (gtk_builder_get_object (builder, "notebook"));
+    prefs_dialog = HDY_PREFERENCES_WINDOW (gtk_builder_get_object (builder, "preferences_dialog"));
 
     spin_button = GTK_SPIN_BUTTON (gtk_builder_get_object (builder, "processes_interval_spinner"));
 
@@ -232,43 +257,77 @@ create_preferences_dialog (GsmApplication *app)
     g_signal_connect (G_OBJECT (spin_button), "focus_out_event",
                       G_CALLBACK (SBU::callback), &interval_updater);
 
-    smooth_button = GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "smooth_button"));
-    g_settings_bind(app->settings->gobj (), SmoothRefresh::KEY.c_str(), smooth_button, "active", G_SETTINGS_BIND_DEFAULT);
+    smooth_switch = GTK_SWITCH (gtk_builder_get_object (builder, "smooth_switch"));
+    g_settings_bind(app->settings->gobj (), SmoothRefresh::KEY.c_str(), smooth_switch, "active", G_SETTINGS_BIND_DEFAULT);
 
-    check_button = GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "check_button"));
+    check_switch = GTK_SWITCH (gtk_builder_get_object (builder, "check_switch"));
     g_settings_bind (app->settings->gobj (), GSM_SETTING_SHOW_KILL_DIALOG,
-                     check_button, "active",
+                     check_switch, "active",
                      G_SETTINGS_BIND_DEFAULT);
 
-    GtkCheckButton *solaris_button = GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "solaris_button"));
+    GtkSwitch *solaris_switch = GTK_SWITCH (gtk_builder_get_object (builder, "solaris_switch"));
     g_settings_bind (app->settings->gobj (), GSM_SETTING_SOLARIS_MODE,
-                     solaris_button, "active",
+                     solaris_switch, "active",
                      G_SETTINGS_BIND_DEFAULT);
 
-    GtkCheckButton *draw_stacked_button = GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "draw_stacked_button"));
+    GtkSwitch *proc_mem_in_iec_switch = GTK_SWITCH (gtk_builder_get_object (builder, "proc_mem_in_iec_switch"));
+    g_settings_bind(app->settings->gobj (), GSM_SETTING_PROCESS_MEMORY_IN_IEC,
+                    proc_mem_in_iec_switch, "active",
+                    G_SETTINGS_BIND_DEFAULT);
+
+    GtkSwitch *logarithmic_scale_switch = GTK_SWITCH (gtk_builder_get_object (builder, "logarithmic_scale_switch"));
+    g_settings_bind (app->settings->gobj (), GSM_SETTING_LOGARITHMIC_SCALE,
+                     logarithmic_scale_switch, "active",
+                     G_SETTINGS_BIND_DEFAULT);
+
+    GtkSwitch *draw_stacked_switch = GTK_SWITCH (gtk_builder_get_object (builder, "draw_stacked_switch"));
     g_settings_bind (app->settings->gobj (), GSM_SETTING_DRAW_STACKED,
-                     draw_stacked_button, "active",
+                     draw_stacked_switch, "active",
                      G_SETTINGS_BIND_DEFAULT);
 
-    GtkCheckButton *draw_smooth_button = GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "draw_smooth_button"));
+    GtkSwitch *draw_smooth_switch = GTK_SWITCH (gtk_builder_get_object (builder, "draw_smooth_switch"));
     g_settings_bind (app->settings->gobj (), GSM_SETTING_DRAW_SMOOTH,
-                     draw_smooth_button, "active",
+                     draw_smooth_switch, "active",
                      G_SETTINGS_BIND_DEFAULT);
 
+    GtkSwitch *res_mem_in_iec_switch = GTK_SWITCH (gtk_builder_get_object (builder, "res_mem_in_iec_switch"));
+    g_settings_bind(app->settings->gobj (), GSM_SETTING_RESOURCES_MEMORY_IN_IEC,
+                    res_mem_in_iec_switch, "active",
+                    G_SETTINGS_BIND_DEFAULT);
+
     create_field_page (builder, GTK_TREE_VIEW (app->tree), "proctree");
 
     update = (gfloat) app->config.graph_update_interval;
-    spin_button = GTK_SPIN_BUTTON (gtk_builder_get_object (builder, "resources_interval_spinner"));                                                 
+    spin_button = GTK_SPIN_BUTTON (gtk_builder_get_object (builder, "resources_interval_spinner"));
     adjustment = gtk_spin_button_get_adjustment (spin_button);
-    gtk_adjustment_configure (adjustment, update / 1000.0, 0.25,
-                              100.0, 0.25, 1.0, 0);
+    gtk_adjustment_configure (adjustment, update / 1000.0, 0.05,
+                              10.0, 0.05, 0.5, 0);
     g_signal_connect (G_OBJECT (spin_button), "focus_out_event",
                       G_CALLBACK(SBU::callback),
                       &graph_interval_updater);
 
-    GtkCheckButton *bits_button = GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "bits_button"));
+    update = (gfloat) app->config.graph_data_points;
+    GtkRange* range = GTK_RANGE (gtk_builder_get_object (builder, "graph_data_points_scale"));
+    adjustment = gtk_range_get_adjustment (range);
+    gtk_adjustment_configure (adjustment, update, 30,
+                              600, 10, 60, 0);
+    g_signal_connect (G_OBJECT (range), "value-changed",
+                      G_CALLBACK(ScaleUpdater::callback),
+                      &graph_points_updater);
+
+    GtkSwitch *bits_switch = GTK_SWITCH (gtk_builder_get_object (builder, "bits_switch"));
     g_settings_bind(app->settings->gobj (), GSM_SETTING_NETWORK_IN_BITS,
-                    bits_button, "active",
+                    bits_switch, "active",
+                    G_SETTINGS_BIND_DEFAULT);
+
+    GtkSwitch *bits_unit_switch = GTK_SWITCH (gtk_builder_get_object (builder, "bits_unit_switch"));
+    g_settings_bind(app->settings->gobj (), GSM_SETTING_NETWORK_TOTAL_UNIT,
+                    bits_unit_switch, "active",
+                    G_SETTINGS_BIND_DEFAULT);
+
+    GtkSwitch *bits_total_switch = GTK_SWITCH (gtk_builder_get_object (builder, "bits_total_switch"));
+    g_settings_bind(app->settings->gobj (), GSM_SETTING_NETWORK_TOTAL_IN_BITS,
+                    bits_total_switch, "active",
                     G_SETTINGS_BIND_DEFAULT);
 
     update = (gfloat) app->config.disks_update_interval;
@@ -281,28 +340,22 @@ create_preferences_dialog (GsmApplication *app)
                       &disks_interval_updater);
 
 
-    check_button = GTK_CHECK_BUTTON (gtk_builder_get_object (builder, "all_devices_check"));
+    check_switch = GTK_SWITCH (gtk_builder_get_object (builder, "all_devices_check"));
     g_settings_bind (app->settings->gobj (), GSM_SETTING_SHOW_ALL_FS,
-                     check_button, "active",
+                     check_switch, "active",
                      G_SETTINGS_BIND_DEFAULT);
 
     create_field_page (builder, GTK_TREE_VIEW (app->disk_list), "disktreenew");
 
     gtk_window_set_transient_for (GTK_WINDOW (prefs_dialog), GTK_WINDOW (GsmApplication::get()->main_window));
+    gtk_window_set_modal (GTK_WINDOW (prefs_dialog), TRUE);
 
     gtk_widget_show_all (GTK_WIDGET (prefs_dialog));
-    g_signal_connect (G_OBJECT (prefs_dialog), "response",
-                      G_CALLBACK (prefs_dialog_button_pressed), app);
+    g_signal_connect (G_OBJECT (prefs_dialog), "delete-event",
+                      G_CALLBACK (prefs_dialog_delete_event), NULL);
 
-    auto current_tab = app->settings->get_string(GSM_SETTING_CURRENT_TAB);
-    if (current_tab == "processes")
-        gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 0);
-    else if (current_tab == "resources")
-        gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 1);
-    else if (current_tab == "disks")
-        gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook), 2);
+    gtk_window_present (GTK_WINDOW (prefs_dialog));
 
     gtk_builder_connect_signals (builder, NULL);
     g_object_unref (G_OBJECT (builder));
 }
-
