@@ -3,6 +3,9 @@
 #define _GSM_SETTINGS_KEYS_H_
 
 #define GSM_GSETTINGS_SCHEMA                "org.gnome.gnome-system-monitor"
+#define FONT_SETTINGS_SCHEMA                "org.gnome.desktop.interface"
+
+#define FONT_SETTING_SCALING                "text-scaling-factor"
 
 #define GSM_SETTINGS_CHILD_OPEN_FILES       "openfilestree"
 #define GSM_SETTINGS_CHILD_DISKS            "disktreenew"
@@ -17,15 +20,21 @@
 #define GSM_SETTING_SHOW_DEPENDENCIES       "show-dependencies"
 #define GSM_SETTING_SHOW_KILL_DIALOG        "kill-dialog"
 #define GSM_SETTING_SOLARIS_MODE            "solaris-mode"
+#define GSM_SETTING_PROCESS_MEMORY_IN_IEC   "process-memory-in-iec"
 #define GSM_SETTING_GRAPH_UPDATE_INTERVAL   "graph-update-interval"
 #define GSM_SETTING_CPU_COLORS              "cpu-colors"
 #define GSM_SETTING_MEM_COLOR               "mem-color"
 #define GSM_SETTING_SWAP_COLOR              "swap-color"
 #define GSM_SETTING_NET_IN_COLOR            "net-in-color"
 #define GSM_SETTING_NET_OUT_COLOR           "net-out-color"
+#define GSM_SETTING_LOGARITHMIC_SCALE       "logarithmic-scale"
 #define GSM_SETTING_DRAW_STACKED            "cpu-stacked-area-chart"
 #define GSM_SETTING_DRAW_SMOOTH             "cpu-smooth-graph"
+#define GSM_SETTING_RESOURCES_MEMORY_IN_IEC "resources-memory-in-iec"
 #define GSM_SETTING_NETWORK_IN_BITS         "network-in-bits"
+#define GSM_SETTING_GRAPH_DATA_POINTS       "graph-data-points"
+#define GSM_SETTING_NETWORK_TOTAL_UNIT      "network-total-unit"
+#define GSM_SETTING_NETWORK_TOTAL_IN_BITS   "network-total-in-bits"
 #define GSM_SETTING_SHOW_CPU                "show-cpu"
 #define GSM_SETTING_SHOW_MEM                "show-mem"
 #define GSM_SETTING_SHOW_NETWORK            "show-network"
